import time
import logging
from argparse import ArgumentParser
from pymavlink import mavutil

parser = ArgumentParser(description=__doc__)
parser.add_argument("connection", type=str)
parser.add_argument("-i", "--interval", default=1, type=int, help="Wait interval seconds between sending each packet.")
parser.add_argument("-b", "--baudrate", type=int, help="The baudrate used in a serial connection.")
parser.add_argument("--rtscts", action="store_true", help="Enable RTS/CTS flow control")
args = parser.parse_args()
mavutil.set_dialect("ardupilotmega")
interval = args.interval
last_sent_timesync = 0
packets_sent = 0
packet_loss = 0
packets = []

if args.baudrate != None:
    connection = mavutil.mavlink_connection(args.connection, baud=args.baudrate)
    if args.rtscts:
        connection.set_rtscts(True)
else:
    connection = mavutil.mavlink_connection(args.connection)
 
while True:
    now = time.time()

    message = connection.recv_match(type='COMMAND_ACK')
    if message is None:
        pass
    else:
        print(message)

    if (now - last_sent_timesync > interval):
        # send update
        last_sent_timesync = now
        time_ns = now * 10**9

        connection.mav.command_long_send(
            0,
            0,
            mavutil.mavlink.MAV_CMD_DO_SET_HOME,
            0, # confirmation
            0, # (0, set location specified in msg)
            0, # param2
            0, # param3
            0, # param4
            52.5, # param5
            13.5, # param6
            0 # param9,
            # Elevation models report 0 too at sea
        )
        print("Position update sent")
